@@ -173,7 +173,13 @@ class LocalDiskBackendTestCase(unittest.TestCase):
         src = 'foo/bar/baz/taz'
         with self.backend.open(src, 'w') as f:
             f.write("Hello world!")
-        self.assertEqual(self.backend.slice(src, 5), b"Hello")
+        self.assertEqual(self.backend.slice(src, 5), "Hello")
+
+    def test_slice_no_offset_binary(self):
+        src = 'foo/bar/baz/taz'
+        with self.backend.open(src, 'wb') as f:
+            f.write(b"Hello world!")
+        self.assertEqual(self.backend.slice(src, 5, binary=True), b"Hello")
 
     def test_slice_raises_value_error_on_offset_lt_zero(self):
         src = 'foo/bar/baz/taz'
@@ -222,6 +228,19 @@ class LocalDiskBackendTestCase(unittest.TestCase):
 
         asyncio.run(afunc())
 
+    def test_async_slice_no_offset_binary(self):
+        if not self.backend.has_capability('slice:async'):
+            self.skipTest("Backend does not support asynchronous slicing.")
+        src = 'foo/bar/baz/taz'
+        async def afunc():
+            with self.backend.open(src, 'w') as f:
+                f.write("Hello world!")
+            self.assertEqual(
+                await self.backend.async_slice(src, 5, binary=True), b"Hello"
+            )
+
+        asyncio.run(afunc())
+
     def test_async_offset_after_eof_returns_empty_string(self):
         if not self.backend.has_capability('slice:async'):
             self.skipTest("Backend does not support asynchronous slicing.")
